@@ -11,11 +11,13 @@
 #include "ddeindicatortrayprotocol.h"
 #include "pluginproxyinterface.h"
 
+#include <DIconTheme>
 #include <QDebug>
 
 namespace tray {
 TrayPlugin::TrayPlugin(QObject *parent)
 {
+    Q_UNUSED(parent)
     qRegisterMetaType<TrayList>("TrayList");
     qDBusRegisterMetaType<TrayList>();
 
@@ -46,6 +48,10 @@ void TrayPlugin::init(PluginProxyInterface *proxyInter)
 {
     m_proyInter = proxyInter;
 
+    auto dciPaths = Dtk::Gui::DIconTheme::dciThemeSearchPaths();
+    dciPaths.prepend(":/dsg-icon/override");
+    Dtk::Gui::DIconTheme::setDciThemeSearchPaths(dciPaths);
+
     auto sniProtocol = new SniTrayProtocol();
     auto xembedProtocol = new XembedProtocol();
     auto indicatorProtocol = new DDEindicatorProtocol();
