@@ -16,6 +16,8 @@
 #include <DSwitchButton>
 #include <DListView>
 #include <DSpinner>
+#include <DPaletteHelper>
+#include <DGuiApplicationHelper>
 
 #include <QBoxLayout>
 #include <QStandardItemModel>
@@ -24,6 +26,7 @@ BluetoothDeviceItem::BluetoothDeviceItem(QStyle *style, const Device *device, Pl
     : m_style(style)
     , m_device(device)
 {
+    Q_UNUSED(parent)
     m_standardItem = new PluginStandardItem();
 
     m_standardItem->updateIcon(m_device->deviceType().isEmpty() ? QIcon::fromTheme("bluetooth_other")
@@ -67,7 +70,7 @@ BluetoothAdapterItem::BluetoothAdapterItem(Adapter *adapter, QWidget *parent)
     , m_adapterLayout(new QVBoxLayout)
     , m_adapterStateBtn(new DSwitchButton(this))
     , m_myDeviceWidget(new QWidget(this))
-    , m_myDeviceLabel(new QLabel(tr("My Devices"), this))
+    , m_myDeviceLabel(new DLabel(tr("My Devices"), this))
     , m_myDeviceListView(new PluginListView(this))
     , m_myDeviceModel(new QStandardItemModel(m_myDeviceListView))
     , m_otherDeviceControlWidget(new DeviceControlWidget(this))
@@ -78,7 +81,6 @@ BluetoothAdapterItem::BluetoothAdapterItem(Adapter *adapter, QWidget *parent)
     , m_showUnnamedDevices(false)
     , m_stateBtnEnabled(true)
     , m_adapterSwitchEnabled(true)
-    , m_autoFold(true)
     , m_scanTimer(new QTimer(this))
 {
     initUi();
@@ -251,8 +253,7 @@ void BluetoothAdapterItem::onDeviceAdded(const Device *device)
             }
         }
         m_myDeviceWidget->setVisible(m_myDeviceModel->rowCount() > 0 && m_adapterStateBtn->isChecked());
-        if(m_autoFold)
-            m_otherDeviceControlWidget->setExpandState(m_myDeviceModel->rowCount() < 1 && m_adapterStateBtn->isChecked());
+
         if (m_adapterSwitchEnabled) {
             emit deviceCountChanged();
         }
@@ -274,8 +275,6 @@ void BluetoothAdapterItem::onDeviceAdded(const Device *device)
         emit deviceCountChanged();
     }
     m_myDeviceWidget->setVisible(m_myDeviceModel->rowCount() > 0 && m_adapterStateBtn->isChecked());
-    if(m_autoFold)
-        m_otherDeviceControlWidget->setExpandState(m_myDeviceModel->rowCount() < 1 && m_adapterStateBtn->isChecked());
 }
 
 void BluetoothAdapterItem::onDeviceRemoved(const Device *device)
@@ -359,8 +358,10 @@ void BluetoothAdapterItem::initUi()
     m_myDeviceListView->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     QVBoxLayout *myDeviceLayout = new QVBoxLayout(m_myDeviceWidget);
     myDeviceLayout->setSpacing(0);
-    m_myDeviceLabel->setContentsMargins(10, 0, 0, 2);
+    myDeviceLayout->setContentsMargins(0, 0, 0, 0);
+    m_myDeviceLabel->setContentsMargins(10, 0, 0, 6);
     DFontSizeManager::instance()->bind(m_myDeviceLabel, DFontSizeManager::T10);
+    updateMyDeviceLabelTheme();
     myDeviceLayout->addWidget(m_myDeviceLabel);
     myDeviceLayout->addWidget(m_myDeviceListView);
 
@@ -380,7 +381,7 @@ void BluetoothAdapterItem::initUi()
 
     mainLayout->addLayout(m_adapterLayout);
     mainLayout->addWidget(m_myDeviceWidget);
-    mainLayout->addSpacing(5);
+    mainLayout->addSpacing(4);
     mainLayout->addWidget(m_otherDeviceListView);
     mainLayout->addStretch();
 
@@ -457,8 +458,10 @@ void BluetoothAdapterItem::initConnect()
             emit deviceCountChanged();
         }
     });
-    connect(m_otherDeviceControlWidget, &DeviceControlWidget::clicked, this, [this] {
-        m_autoFold = false;
+
+    connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged, this, [this]{
+        updateMyDeviceLabelTheme();
+        update();
     });
 }
 
@@ -516,6 +519,13 @@ void BluetoothAdapterItem::setUnnamedDevicesVisible(bool isShow)
 
 void BluetoothAdapterItem::showEvent(QShowEvent *event)
 {
+    // 设置默认展开状态：只有在没有已配对设备时才展开其他设备列表
+    if (m_adapterSwitchEnabled) {
+        bool shouldExpand = m_myDeviceModel->rowCount() < 1;
+        m_otherDeviceControlWidget->setExpandState(shouldExpand);
+        m_otherDeviceListView->setVisible(shouldExpand);
+    }
+    
     emit deviceCountChanged();
     if (m_adapter->discover()) {
         return;
@@ -527,10 +537,16 @@ void BluetoothAdapterItem::showEvent(QShowEvent *event)
     QWidget::showEvent(event);
 }
 
-void BluetoothAdapterItem::hideEvent(QHideEvent *event)
+void BluetoothAdapterItem::updateMyDeviceLabelTheme()
 {
-    m_autoFold = true;
-    if (m_adapterSwitchEnabled && m_myDeviceModel->rowCount() > 0)
-        m_otherDeviceControlWidget->setExpandState(false);
-    QWidget::hideEvent(event);
+    DPalette palette = DPaletteHelper::instance()->palette(m_myDeviceLabel);
+    QColor textColor;
+    if (DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::LightType) {
+        textColor = Qt::black;
+    } else {
+        textColor = Qt::white;
+    }
+    textColor.setAlphaF(0.60);
+    palette.setColor(QPalette::WindowText, textColor);
+    DPaletteHelper::instance()->setPalette(m_myDeviceLabel, palette);
 }
