@@ -216,6 +216,7 @@ void PowerPlugin::loadPlugin()
         }
         refreshTipsData();
     });
+
     connect(m_systemPowerInter, &SystemPowerInter::BatteryTimeToEmptyChanged, this, &PowerPlugin::refreshTipsData);
     connect(m_systemPowerInter, &SystemPowerInter::BatteryTimeToFullChanged, this, &PowerPlugin::refreshTipsData);
     connect(m_systemPowerInter, &SystemPowerInter::BatteryPercentageChanged, this, &PowerPlugin::refreshTipsData);
@@ -226,6 +227,7 @@ void PowerPlugin::loadPlugin()
 
     onDConfigValueChanged("showTimeToFull");
     m_powerStatusWidget->refreshIcon();
+
 }
 
 void PowerPlugin::refreshPluginItemsVisible()
@@ -278,8 +280,7 @@ void PowerPlugin::refreshTipsData()
     const int batteryState = m_systemPowerInter->batteryStatus();
 
     if (m_batteryStateChangedTimer->isActive()) {
-        if ((batteryState == BatteryState::CHARGING && m_showTimeToFull)
-        || (batteryState == BatteryState::DIS_CHARGING)) {
+        if (m_showTimeToFull && (batteryState == BatteryState::CHARGING || batteryState == BatteryState::DIS_CHARGING)) {
             // 计算期间
             QString tips = tr("Capacity %1 ...").arg(value);
             m_tipsLabel->setText(tips);
