@@ -51,7 +51,7 @@
         <translation>Ausgeschaltet</translation>
     </message>
     <message>
-        <source>Disable Airplane Mode first if you want to connect to a Bluetooth</source>
+        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -385,61 +385,6 @@
         <translation>Thema</translation>
     </message>
 </context>
-<context>
-    <name>MenuWorker</name>
-    <message>
-        <source>Fashion Mode</source>
-        <translation>Design-Modus</translation>
-    </message>
-    <message>
-        <source>Efficient Mode</source>
-        <translation>Effizienzmodus</translation>
-    </message>
-    <message>
-        <source>Top</source>
-        <translation>Oben</translation>
-    </message>
-    <message>
-        <source>Bottom</source>
-        <translation>Unten</translation>
-    </message>
-    <message>
-        <source>Left</source>
-        <translation>Links</translation>
-    </message>
-    <message>
-        <source>Right</source>
-        <translation>Rechts</translation>
-    </message>
-    <message>
-        <source>Keep Shown</source>
-        <translation>Angezeigt lassen</translation>
-    </message>
-    <message>
-        <source>Keep Hidden</source>
-        <translation>Ausgeblendet lassen</translation>
-    </message>
-    <message>
-        <source>Smart Hide</source>
-        <translation>Intelligentes Ausblenden</translation>
-    </message>
-    <message>
-        <source>Mode</source>
-        <translation>Modus</translation>
-    </message>
-    <message>
-        <source>Location</source>
-        <translation>Ort</translation>
-    </message>
-    <message>
-        <source>Status</source>
-        <translation>Status</translation>
-    </message>
-    <message>
-        <source>Dock settings</source>
-        <translation>Dock-Einstellungen</translation>
-    </message>
-</context>
 <context>
     <name>NotificationPlugin</name>
     <message>
