@@ -23,7 +23,7 @@
     </message>
     <message>
         <source>Airplane mode settings</source>
-        <translation>Ustawienia trybu samolotowego</translation>
+        <translation>Ustawienia Trybu samolotowego</translation>
     </message>
 </context>
 <context>
@@ -51,8 +51,8 @@
         <translation>Wyłączony</translation>
     </message>
     <message>
-        <source>Disable Airplane Mode first if you want to connect to a Bluetooth</source>
-        <translation>Wyłącz Tryb Samolotowy, aby połączyć się z Bluetooth</translation>
+        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
+        <translation>Najpierw wyłącz [Tryb Samolotowy](#), aby połączyć się z Bluetooth</translation>
     </message>
 </context>
 <context>
@@ -385,61 +385,6 @@
         <translation>Motyw</translation>
     </message>
 </context>
-<context>
-    <name>MenuWorker</name>
-    <message>
-        <source>Fashion Mode</source>
-        <translation>Tryb modny</translation>
-    </message>
-    <message>
-        <source>Efficient Mode</source>
-        <translation>Tryb wydajny</translation>
-    </message>
-    <message>
-        <source>Top</source>
-        <translation>Góra</translation>
-    </message>
-    <message>
-        <source>Bottom</source>
-        <translation>Dół</translation>
-    </message>
-    <message>
-        <source>Left</source>
-        <translation>Lewo</translation>
-    </message>
-    <message>
-        <source>Right</source>
-        <translation>Prawo</translation>
-    </message>
-    <message>
-        <source>Keep Shown</source>
-        <translation>Zawsze wyświetlaj</translation>
-    </message>
-    <message>
-        <source>Keep Hidden</source>
-        <translation>Zawsze ukrywaj</translation>
-    </message>
-    <message>
-        <source>Smart Hide</source>
-        <translation>Inteligentne ukrywanie</translation>
-    </message>
-    <message>
-        <source>Mode</source>
-        <translation>Tryb</translation>
-    </message>
-    <message>
-        <source>Location</source>
-        <translation>Położenie</translation>
-    </message>
-    <message>
-        <source>Status</source>
-        <translation>Status</translation>
-    </message>
-    <message>
-        <source>Dock settings</source>
-        <translation>Ustawienia doku</translation>
-    </message>
-</context>
 <context>
     <name>NotificationPlugin</name>
     <message>
@@ -494,7 +439,7 @@
     </message>
     <message>
         <source>Balance Performance</source>
-        <translation>Zrównoważona wydajność</translation>
+        <translation>Wydajność zbalansowana</translation>
     </message>
 </context>
 <context>
@@ -512,11 +457,11 @@
     </message>
     <message>
         <source>Capacity %1, %2 min remaining</source>
-        <translation>Poziom: %1, pozostało: %2min</translation>
+        <translation>Pojemność %1, pozostało: %2min</translation>
     </message>
     <message>
         <source>Capacity %1, %2 hr %3 min remaining</source>
-        <translation>Poziom: %1, pozostało: %2:%3</translation>
+        <translation>Pojemność %1, pozostało: %2:%3</translation>
     </message>
     <message>
         <source>Charging %1, %2 min until full</source>
