@@ -24,7 +24,12 @@ void TipsWidget::setText(const QString &text)
     QTextDocument document;
     document.setHtml(text);
     // 同时去掉两边的空白信息，例如qBittorrent的提示
-    m_text = document.toPlainText().simplified();
+    QString newText = document.toPlainText().simplified();
+    if (m_text == newText) {
+        return;
+    }
+
+    m_text = newText;
 
 #if 0 //测试时可以使用下面的语句
     // FIXME:藏语字体绘制会有异常，设置高度时需要使用fontMetrics().boundingRect()去获取整体的边界矩形的高度，
@@ -32,8 +37,7 @@ void TipsWidget::setText(const QString &text)
     m_text = "བོད་སྐད་ཡིག་གཟུགས་ཚད་ལེན་ཚོད་ལྟའི་སྐོར་གྱི་རྗོད་ཚིག";
 #endif
 
-    setFixedSize(fontMetrics().horizontalAdvance(m_text), fontMetrics().boundingRect(m_text).height());
-
+    updateGeometry();
     update();
 
 #ifndef QT_NO_ACCESSIBILITY
@@ -47,17 +51,12 @@ void TipsWidget::setText(const QString &text)
 void TipsWidget::setTextList(const QStringList &textList)
 {
     m_type = TipsWidget::MultiLine;
+    if (textList == m_textList) {
+        return;
+    }
     m_textList = textList;
 
-    int width = 0;
-    int height = 0;
-    for (const QString& text : m_textList) {
-        width = qMax(width, fontMetrics().horizontalAdvance(text));
-        height += fontMetrics().boundingRect(text).height();
-    }
-
-    setFixedSize(width, height);
-
+    updateGeometry();
     update();
 }
 
@@ -96,25 +95,45 @@ void TipsWidget::paintEvent(QPaintEvent *event)
     }
 }
 
+QSize TipsWidget::sizeHint() const
+{
+    const QFontMetrics fm = fontMetrics();
+
+    switch (m_type) {
+    case SingleLine: {
+        return QSize(fm.horizontalAdvance(m_text),
+                    fm.boundingRect(m_text).height());
+    }
+    case MultiLine: {
+        int maxWidth = 0;
+        int totalHeight = 0;
+        for (const QString& text : m_textList) {
+            maxWidth = qMax(maxWidth, fm.horizontalAdvance(text));
+            totalHeight += fm.boundingRect(text).height();
+        }
+
+        return QSize(maxWidth, totalHeight);
+    }
+    }
+
+    Q_UNREACHABLE_RETURN(QSize(0, 0));
+}
+
 bool TipsWidget::event(QEvent *event)
 {
     if (event->type() == QEvent::FontChange) {
-        switch (m_type) {
-        case SingleLine:
-        {
-            setText(m_text);
-            break;
-        }
-        case MultiLine:
-        {
-            setTextList(m_textList);
-            break;
-        }
-        }
+        updateGeometry();
+        update();
     } else if (event->type() == QEvent::MouseButtonRelease
                && static_cast<QMouseEvent *>(event)->button() == Qt::RightButton) {
         return true;
     }
     return QFrame::event(event);
 }
+
+QSize TipsWidget::minimumSizeHint() const
+{
+    return sizeHint();
+}
+
 }
