@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="zh_CN">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
 <context>
     <name>PluginItem</name>
     <message>
@@ -14,12 +12,12 @@
     <message>
         <location filename="../quickpluginitem.cpp" line="160"/>
         <source>Remove from dock</source>
-        <translation>从任务栏移除</translation>
+        <translation>在任务栏上移除</translation>
     </message>
     <message>
         <location filename="../quickpluginitem.cpp" line="160"/>
         <source>Pin to dock</source>
-        <translation>固定到任务栏</translation>
+        <translation>在任务栏上驻留</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
